@@ -21,78 +21,80 @@
 #include "mergedialog.h"
 
 #include <qbuttongroup.h>
-#include <KComboBox>
 #include <qlabel.h>
-#include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qstyle.h>
 #include <QGridLayout>
-#include <QBoxLayout>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
-#include <klocale.h>
+#include <KComboBox>
+#include <KConfigGroup>
+#include <KLocalizedString>
 
 #include "misc.h"
 #include "cvsserviceinterface.h"
 
 
-MergeDialog::MergeDialog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service,
+MergeDialog::MergeDialog(OrgKdeCervisia5CvsserviceCvsserviceInterface* service,
                          QWidget *parent)
-    : KDialog(parent),
+    : QDialog(parent),
       cvsService(service)
 {
-    setCaption(i18n("CVS Merge"));
+    setWindowTitle(i18n("CVS Merge"));
     setModal(true);
-    setButtons(Ok | Cancel);
-    setDefaultButton(Ok);
-    showButtonSeparator(true);
 
-    int const iComboBoxMinWidth(30 * fontMetrics().width('0'));
-    int const iWidgetIndent(style()->pixelMetric(QStyle::PM_ExclusiveIndicatorWidth) + 6);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
 
-    QFrame* mainWidget = new QFrame(this);
-    setMainWidget(mainWidget);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    QBoxLayout *layout = new QVBoxLayout(mainWidget);
-    layout->setSpacing(spacingHint());
-    layout->setMargin(0);
+    const int iComboBoxMinWidth(30 * fontMetrics().width('0'));
+    const int iWidgetIndent(style()->pixelMetric(QStyle::PM_ExclusiveIndicatorWidth) + 6);
 
-    bybranch_button = new QRadioButton(i18n("Merge from &branch:"), mainWidget);
+    bybranch_button = new QRadioButton(i18n("Merge from &branch:"));
     bybranch_button->setChecked(true);
-    layout->addWidget(bybranch_button);
+    mainLayout->addWidget(bybranch_button);
 
-    branch_combo = new KComboBox(mainWidget);
+    branch_combo = new KComboBox;
     branch_combo->setEditable(true);
     branch_combo->setMinimumWidth(iComboBoxMinWidth);
+    mainLayout->addWidget(branch_combo);
 
-    branch_button = new QPushButton(i18n("Fetch &List"), mainWidget);
-    connect( branch_button, SIGNAL(clicked()),
-             this, SLOT(branchButtonClicked()) );
+    branch_button = new QPushButton(i18n("Fetch &List"));
+    mainLayout->addWidget(branch_button);
+    connect(branch_button, SIGNAL(clicked()), this, SLOT(branchButtonClicked()));
 
     QBoxLayout *branchedit_layout = new QHBoxLayout();
-    layout->addLayout(branchedit_layout);
     branchedit_layout->addSpacing(iWidgetIndent);
     branchedit_layout->addWidget(branch_combo, 2);
     branchedit_layout->addWidget(branch_button, 0);
+    mainLayout->addLayout(branchedit_layout);
 
-    bytags_button = new QRadioButton(i18n("Merge &modifications:"), mainWidget);
-    layout->addWidget(bytags_button);
+    bytags_button = new QRadioButton(i18n("Merge &modifications:"));
+    mainLayout->addWidget(bytags_button);
 
-    QLabel *tag1_label = new QLabel(i18n("between tag: "), mainWidget);
-    tag1_combo = new KComboBox(mainWidget);
+    QLabel *tag1_label = new QLabel(i18n("between tag: "));
+
+    tag1_combo = new KComboBox;
     tag1_combo->setEditable(true);
     tag1_combo->setMinimumWidth(iComboBoxMinWidth);
 
-    QLabel *tag2_label = new QLabel(i18n("and tag: "), mainWidget);
-    tag2_combo = new KComboBox(mainWidget);
+    QLabel *tag2_label = new QLabel(i18n("and tag: "));
+
+    tag2_combo = new KComboBox;
     tag2_combo->setEditable(true);
     tag2_combo->setMinimumWidth(iComboBoxMinWidth);
 
-    tag_button = new QPushButton(i18n("Fetch L&ist"), mainWidget);
-    connect( tag_button, SIGNAL(clicked()),
-             this, SLOT(tagButtonClicked()) );
+    tag_button = new QPushButton(i18n("Fetch L&ist"));
+    connect(tag_button, SIGNAL(clicked()), this, SLOT(tagButtonClicked()));
 
     QGridLayout *tagsedit_layout = new QGridLayout();
-    layout->addLayout( tagsedit_layout );
     tagsedit_layout->addItem(new QSpacerItem(iWidgetIndent, 0), 0, 0);
     tagsedit_layout->setColumnStretch(0, 0);
     tagsedit_layout->setColumnStretch(1, 1);
@@ -103,12 +105,14 @@ MergeDialog::MergeDialog(OrgKdeCervisiaCvsserviceCvsserviceInterface* service,
     tagsedit_layout->addWidget(tag2_label, 1, 1);
     tagsedit_layout->addWidget(tag2_combo, 1, 2);
     tagsedit_layout->addWidget(tag_button, 0, 3, 2, 1);
+    mainLayout->addLayout( tagsedit_layout );
 
-    QButtonGroup* group = new QButtonGroup(mainWidget);
+    QButtonGroup* group = new QButtonGroup(this);
     group->addButton(bybranch_button);
     group->addButton(bytags_button);
-    connect( group, SIGNAL(buttonClicked(int)),
-             this, SLOT(toggled()) );
+    connect(group, SIGNAL(buttonClicked(int)), this, SLOT(toggled()));
+
+    mainLayout->addWidget(buttonBox);
 
     // dis-/enable the widgets
     toggled();
@@ -170,7 +174,6 @@ void MergeDialog::toggled()
         tag1_combo->setFocus();
 }
 
-#include "mergedialog.moc"
 
 
 // Local Variables:
